@@ -3,6 +3,7 @@
 // #![warn(rust_2018_idioms)]
 #![forbid(unsafe_code)]
 // #![warn(clippy::restriction)]
+
 /**
  * MIT License
  *
@@ -31,8 +32,8 @@ mod invidious;
 mod player;
 mod song;
 mod songtag;
-#[cfg(feature = "mpris")]
-mod souvlaki;
+// #[cfg(feature = "mpris")]
+// mod souvlaki;
 #[cfg(feature = "cover")]
 mod ueberzug;
 mod ui;
