@@ -1,9 +1,8 @@
-//
-// model.rs
-// Copyright (C) 2019 gmg137 <gmg137@live.com>
-// Distributed under terms of the GPLv3 license.
-//
-
+/**
+ * model.rs
+ * Copyright (C) 2019 gmg137 <gmg137@live.com>
+ * Distributed under terms of the GPLv3 license.
+ */
 mod model;
 
 use super::encrypt::Crypto;
@@ -110,8 +109,8 @@ impl Api {
                     .post(&url)
                     .set("Cookie", "os=pc; appver=2.7.1.198277")
                     .set("Accept", "*/*")
-                    // .set("Accept-Encoding", "gzip,deflate,br")
-                    .set("Accept-Encoding", "identity")
+                    .set("Accept-Encoding", "gzip,deflate,br")
+                    // .set("Accept-Encoding", "identity")
                     .set("Accept-Language", "en-US,en;q=0.5")
                     .set("Connection", "keep-alive")
                     .set("Content-Type", "application/x-www-form-urlencoded")
