@@ -1,9 +1,7 @@
 //! # Popups
 //!
-//!
 //! Popups components
 
-use super::ColorConfig;
 /**
  * MIT License
  *
@@ -27,6 +25,7 @@ use super::ColorConfig;
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
+use super::ColorConfig;
 use crate::ui::components::StyleColorSymbol;
 use crate::ui::{CEMsg, IdColorEditor, Msg};
 use lazy_static::lazy_static;
@@ -188,7 +187,10 @@ impl Component<Msg, NoUserEvent> for CESelectColor {
             Event::Keyboard(KeyEvent {
                 code: Key::Esc | Key::Char('q'),
                 ..
-            }) => return Some(Msg::ColorEditor(CEMsg::ColorEditorCloseCancel)),
+            }) => match self.state() {
+                State::One(_) => return Some(Msg::ColorEditor(CEMsg::ColorEditorCloseCancel)),
+                _ => self.perform(Cmd::Cancel),
+            },
             Event::Keyboard(KeyEvent {
                 code: Key::Char('h'),
                 modifiers: KeyModifiers::CONTROL,
