@@ -86,51 +86,63 @@ impl Model {
         }
     }
 
+    #[allow(clippy::cast_sign_loss)]
     pub fn progress_update(&mut self) {
-        if let Ok((new_prog, time_pos, duration)) = self.player.get_progress() {
+        if let Ok((progress, time_pos, duration)) = self.player.get_progress() {
             // for unsupported file format, don't update progress
             if duration == 0 {
                 return;
             }
-            // below line is left for debug, for the bug of comsume 2 or more songs when start app
-            // eprintln!("{},{},{}", new_prog, time_pos, duration);
 
-            if time_pos >= duration {
+            // if time_pos >= duration {
+            //     self.status = Some(Status::Stopped);
+            //     return;
+            // }
+            // if time_pos > self.time_pos && time_pos - self.time_pos < 1 {
+            //     return;
+            // }
+
+            self.time_pos = time_pos;
+            if self.time_pos_elapsed.elapsed().as_secs() > duration as u64 {
                 self.status = Some(Status::Stopped);
                 return;
             }
-
-            if time_pos > self.time_pos && time_pos - self.time_pos < 1 {
-                return;
-            }
-            self.time_pos = time_pos;
-            let mut new_prog = new_prog / 100.0;
-            if new_prog > 1.0 {
-                new_prog = 1.0;
-            }
-            self.app
-                .attr(
-                    &Id::Progress,
-                    Attribute::Value,
-                    AttrValue::Payload(PropPayload::One(PropValue::F64(new_prog))),
-                )
-                .ok();
-
-            self.app
-                .attr(
-                    &Id::Progress,
-                    Attribute::Text,
-                    AttrValue::String(format!(
-                        "{}    -    {}",
-                        Song::duration_formatted_short(&Duration::from_secs(
-                            self.time_pos.try_into().unwrap_or(0)
-                        )),
-                        Song::duration_formatted_short(&Duration::from_secs(
-                            duration.try_into().unwrap_or(0)
-                        ))
-                    )),
-                )
-                .ok();
+            let new_prog = Self::progress_safeguard(progress);
+            self.progress_set(new_prog, duration);
         }
     }
+
+    fn progress_safeguard(progress: f64) -> f64 {
+        let mut new_prog = progress / 100.0;
+        if new_prog > 1.0 {
+            new_prog = 1.0;
+        }
+        new_prog
+    }
+
+    fn progress_set(&mut self, progress: f64, duration: i64) {
+        self.app
+            .attr(
+                &Id::Progress,
+                Attribute::Value,
+                AttrValue::Payload(PropPayload::One(PropValue::F64(progress))),
+            )
+            .ok();
+
+        self.app
+            .attr(
+                &Id::Progress,
+                Attribute::Text,
+                AttrValue::String(format!(
+                    "{}    -    {}",
+                    Song::duration_formatted_short(&Duration::from_secs(
+                        self.time_pos.try_into().unwrap_or(0)
+                    )),
+                    Song::duration_formatted_short(&Duration::from_secs(
+                        duration.try_into().unwrap_or(0)
+                    ))
+                )),
+            )
+            .ok();
+    }
 }
