@@ -2,8 +2,6 @@
 //!
 //! `Utils` implements utilities functions to work with layouts
 
-// pub mod activity;
-// mod activity;
 /**
  * MIT License
  *
@@ -27,6 +25,8 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
+// pub mod activity;
+// mod activity;
 pub mod components;
 pub mod model;
 
@@ -368,15 +368,15 @@ pub enum Id {
 
 #[derive(Debug, Eq, PartialEq, Clone, Hash)]
 pub enum IdTagEditor {
-    TECounterDelete,
-    TEHelpPopup,
-    TELabelHint,
-    TEInputArtist,
-    TEInputTitle,
-    TERadioTag,
-    TESelectLyric,
-    TETableLyricOptions,
-    TETextareaLyric,
+    CounterDelete,
+    HelpPopup,
+    LabelHint,
+    InputArtist,
+    InputTitle,
+    RadioTag,
+    SelectLyric,
+    TableLyricOptions,
+    TextareaLyric,
 }
 #[derive(Debug, Eq, PartialEq, Clone, Hash)]
 pub enum IdColorEditor {
