@@ -1,8 +1,7 @@
 //! ## Model
 //!
 //! app model
-use crate::player::GeneralP;
-use crate::ui::components::{load_alacritty_theme, ColorConfig};
+
 /**
  * MIT License
  *
@@ -26,6 +25,8 @@ use crate::ui::components::{load_alacritty_theme, ColorConfig};
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
+use crate::player::GeneralP;
+use crate::ui::components::{load_alacritty_theme, ColorConfig};
 use crate::ui::{
     model::UpdateComponents, CEMsg, GSMsg, Id, IdColorEditor, IdKeyEditor, IdTagEditor, KEMsg,
     LIMsg, Model, Msg, PLMsg, StatusLine, TEMsg, YSMsg,
@@ -1026,6 +1027,9 @@ impl Model {
                 if self.app.mounted(&Id::YoutubeSearchTablePopup) {
                     assert!(self.app.umount(&Id::YoutubeSearchTablePopup).is_ok());
                 }
+                if let Err(e) = self.update_photo() {
+                    self.mount_error_popup(format!("update photo error: {}", e).as_ref());
+                }
                 self.app.unlock_subs();
             }
             YSMsg::TablePopupNext => {
@@ -1042,6 +1046,10 @@ impl Model {
                 if self.app.mounted(&Id::YoutubeSearchTablePopup) {
                     assert!(self.app.umount(&Id::YoutubeSearchTablePopup).is_ok());
                 }
+                if let Err(e) = self.update_photo() {
+                    self.mount_error_popup(format!("update photo error: {}", e).as_ref());
+                }
+
                 self.app.unlock_subs();
             }
         }
@@ -1184,37 +1192,35 @@ impl Model {
             }
             TEMsg::TEInputArtistBlurDown | TEMsg::TERadioTagBlurUp => {
                 self.app
-                    .active(&Id::TagEditor(IdTagEditor::TEInputTitle))
+                    .active(&Id::TagEditor(IdTagEditor::InputTitle))
                     .ok();
             }
             TEMsg::TEInputTitleBlurDown | TEMsg::TETableLyricOptionsBlurUp => {
-                self.app
-                    .active(&Id::TagEditor(IdTagEditor::TERadioTag))
-                    .ok();
+                self.app.active(&Id::TagEditor(IdTagEditor::RadioTag)).ok();
             }
             TEMsg::TERadioTagBlurDown | TEMsg::TESelectLyricBlurUp => {
                 self.app
-                    .active(&Id::TagEditor(IdTagEditor::TETableLyricOptions))
+                    .active(&Id::TagEditor(IdTagEditor::TableLyricOptions))
                     .ok();
             }
             TEMsg::TETableLyricOptionsBlurDown | TEMsg::TECounterDeleteBlurUp => {
                 self.app
-                    .active(&Id::TagEditor(IdTagEditor::TESelectLyric))
+                    .active(&Id::TagEditor(IdTagEditor::SelectLyric))
                     .ok();
             }
             TEMsg::TESelectLyricBlurDown | TEMsg::TETextareaLyricBlurUp => {
                 self.app
-                    .active(&Id::TagEditor(IdTagEditor::TECounterDelete))
+                    .active(&Id::TagEditor(IdTagEditor::CounterDelete))
                     .ok();
             }
             TEMsg::TECounterDeleteBlurDown | TEMsg::TEInputArtistBlurUp => {
                 self.app
-                    .active(&Id::TagEditor(IdTagEditor::TETextareaLyric))
+                    .active(&Id::TagEditor(IdTagEditor::TextareaLyric))
                     .ok();
             }
             TEMsg::TETextareaLyricBlurDown | TEMsg::TEInputTitleBlurUp => {
                 self.app
-                    .active(&Id::TagEditor(IdTagEditor::TEInputArtist))
+                    .active(&Id::TagEditor(IdTagEditor::InputArtist))
                     .ok();
             }
             TEMsg::TECounterDeleteOk => {
@@ -1227,10 +1233,8 @@ impl Model {
                 }
             }
             TEMsg::TEHelpPopupClose => {
-                if self.app.mounted(&Id::TagEditor(IdTagEditor::TEHelpPopup)) {
-                    self.app
-                        .umount(&Id::TagEditor(IdTagEditor::TEHelpPopup))
-                        .ok();
+                if self.app.mounted(&Id::TagEditor(IdTagEditor::HelpPopup)) {
+                    self.app.umount(&Id::TagEditor(IdTagEditor::HelpPopup)).ok();
                 }
             }
             TEMsg::TEHelpPopupShow => {
@@ -1267,7 +1271,7 @@ impl Model {
                 }
                 UpdateComponents::DownloadSuccess => {
                     self.update_status_line(StatusLine::Success);
-                    if self.app.mounted(&Id::TagEditor(IdTagEditor::TELabelHint)) {
+                    if self.app.mounted(&Id::TagEditor(IdTagEditor::LabelHint)) {
                         self.umount_tageditor();
                     }
                 }
